#################################################################################################
# Laura McDuffie, University of Alaska Anchorage, USFWS - Lesser Yellowlegs
# Code to support: Differential harvest exposure of Lesser Yellowlegs during autumn migration.
# Author: Laura McDuffie, laura_mcduffie@fws.gov
# Step 1: Predict daily locations from irregularly recorded GPS tracking data using
#   continuous time model of Ian Jonsen, implemented in foieGras package
#################################################################################################

# load libraries from config file
source("0-config.r")

# Load GPS-Argos data recorded by Lotek pinpoint GPS-Argos tags
LEYE.pop <-read.csv("data/All_pops_21Oct.csv")

#### Format according to needs of foieGras

# Convert id to a character
LEYE.pop$id <-as.character(LEYE.pop$id)

# convert lc to a character
LEYE.pop$lc <-as.character(LEYE.pop$lc)

# convert smaj, smin, and eor to a double integer
LEYE.pop$smaj <-as.double(LEYE.pop$smaj) 
LEYE.pop$smin <-as.double(LEYE.pop$smin)
LEYE.pop$eor <-as.double(LEYE.pop$eor)

#convert date to date time
LEYE.pop$date <-as.Date(LEYE.pop$date,format = "%m/%d/%Y")
LEYE.pop$date <-as.POSIXct(LEYE.pop$date, format = "%m/%d/%y %H:%M:%S")

### Dataset checks on All_pops.csv. After these checks, original dataset corrected and now All_pops_21Oct.csv
### Dataset now is based on this: All_pops_21Oct.csv
### Only includes data on or before October 21 from birds tagged in 2018, 2019, and 2020
# add doy column
LEYE.pop$doy = yday(LEYE.pop$date)
# June 5 = 156
# October 21 = day of year 294
LEYE.pop = subset(LEYE.pop, doy %in% c(156:294)) # June 5 to October 21...check to make sure this is ok (i.e. that there were no transmissions back on breeding ground after return)
LEYE.pop$doy = NULL

# Check that all are south of 23 degrees latitude
ids = unique(LEYE.pop$id)
result <- vector("numeric", length(ids)) # prepare a container
 for (i in 1:length(ids)) {
   ind = subset(LEYE.pop, id == ids[i])
   l = min(ind$lat)
   result[i] <- l
 }
 result = data.frame(result)
 result$id = ids

# remove extra columns
LEYE.pop <- LEYE.pop[,1:8]

# remove second year of tracking for individual that was tracked with two separate tags across two year
LEYE.pop = LEYE.pop[!LEYE.pop$id=="180793",] 
# 110 tags, 86 individuals included

#open as a tibble to make sure all columns are the correct data type.
# id=char, date=dttm, lc=chr, lon=dbl, lat=dbl, smaj=dbl, smin=dbl, eor=dbl
LEYE.pop <- as_tibble(LEYE.pop)
LEYE.pop

## fit foieGras model
fit <- fit_ssm(LEYE.pop, vmax = 10, model = "rw", time.step = 24, verbose = 0)

## map predicted values and observations
## Note as of July/August 2020 this now includes error ellipse plotting
fmap(fit, what="predicted", obs = TRUE)

plocs <- grab(fit, what="predicted", as_sf = FALSE)

# get population assignments
pops <-read.csv("data/LEYE_actual_21Oct.csv")
pops <-pops[!duplicated(pops$id), c(1,3,7)]

# assign breeding populations to ssm-predicted locations
d = merge.data.frame(plocs, pops, by = "id") 

# export SSM predictions
save(d, file="results/fG_LEYE_rw.RData")
write.csv(d,'results/fg_LEYE_rw.csv', row.names = FALSE)


