#################################################################################################
# Laura McDuffie, University of Alaska Anchorage, USFWS - Lesser Yellowlegs
# Code to support: Differential harvest exposure of Lesser Yellowlegs during autumn migration
# Authors: Laura McDuffie, laura_mcduffie@fws.gov, Autumn-Lynn Harrison, HarrisonAL@si.edu
#
# Step 2: Assign each predicted daily location to a harvest zone (shapefiles provided)
#  Format for generalized additive model (Step 3)

#  Two sets of shapefiles:
#  File 02a_
#    Broad Zones (data/harvestzone_shape)
#  File 02b_
#    Narrower Zones new May 2020 (data/harvestzone_shape_narrow) 
#      *Note, Narrow zones have different naming convention than Broad Zones
#             Used for analysis
#################################################################################################

# load libraries from config file
source("0-config.r")

################################################
# NARROW ZONES
# Read in shapefiles of harvest zones, updated narrow shapefiles
# Shapefiles provided by L. McDuffie
################################################

#read in first polygon shapefile
Carib <- readOGR('data/harvestzone_shape_narrow_updated/caribbean_zone.shp')
Carib$Name="Carib"

#read in second polygon shapefile
Guianas <- readOGR('data/harvestzone_shape_narrow_updated/guianas_zone_update.shp')
Guianas$Name="Guianas"

#read in second polygon shapefile
Brazil <- readOGR('data/harvestzone_shape_narrow_updated/brazil_zone_updated.shp')
Brazil$Name = "Brazil"

# Check
plot(Carib, col='blue')
plot(Guianas, col='yellow')
plot(Brazil, col='red')

# union intended for combining geometries of overlapping polygons
zones <- union(Carib, Guianas)

zones = bind(Carib, Guianas, Brazil) #bind function from raster. Make sure polygon names are assigned when loading shapefiles
plot(zones)

################################################
# Overlap foieGras predicted bird locations
# with Harvest Zones
################################################

load("results/fG_LEYE_rw.RData") #load outputs of SSM
df = d
coordinates(df) <- c("lon", "lat")

proj4string(df) <- proj4string(zones) #make sure CRS is identical between the two datasets
# Warning: In proj4string(zones) : CRS object has comment, which is lost in output
# indicates may be affected by the change introduced with PROJ 6 (and GDAL 3),

d$zone = as.character(over(df, zones)$Name) #use over function to overlap points and zones and assign zone to new column in point data
d$zone[is.na(d$zone)] <- "Other" # assign NAs to a category "Other"
rm(df)

# check classifications are correct by plotting and color coding by zone
jpeg(filename="plots/PointsInNarrowZones.jpg", width = 700, height = 700)
  plot(zones)
  points(d$lon, d$lat, col=as.factor(d$zone))
  title(main = paste("Narrow Zones:", as.character(sum(!d$zone=="Other")), "locations in zones", sep=" "))
dev.off()

################################################
# Format for mgcv and save
################################################

#### Place each zone in its own separate column (to fit formatting requirements of GAM models)
d$doy = yday(d$date) # use lubridate package to assign day of year for future reference and clean x-axis in initial GAM models

d = data.frame(d)
d$rowid <- rownames(d)

# create separate columns for each Harvest Zone
x = dcast(d, as.numeric(rowid) ~ zone, length, value.var="zone")
# x[4625:4632,] test matches original data
d = cbind(d,x)
rm(x)
save(d, file="results/02_fG_LEYE_rw_ZonesAssigned_Narrow.RData")

