#################################################################################################
# Laura McDuffie, University of Alaska Anchorage, USFWS - Lesser Yellowlegs 
# Code to support: Differential harvest exposure of Lesser Yellowlegs during autumn migration
# 
# Authors: Autumn-Lynn Harrison, HarrisonAL@si.edu, Smithsonian Migratory Bird center
#
# Step 3: Use Generalized additive models to predict probability of occurrence in harvest zones
#################################################################################################

# load libraries from config file
source("0-config.r")

# load data (output of Step 2)
load("results/02_fG_LEYE_rw_ZonesAssigned_Narrow.RData")

# Decision: 
# 1) models grouped by zone, with separate line for each population
# 2) models grouped by population, with separate line for each zone

# Populations
# table(d$pop): Anchorage (3330), Churchill (1920), James Bay (310), Kanuti (550), Mingan (82), Yellowknife (1158)

# pull multinomial model function
#source('mn_Model_Function.R')

d$fid = factor(d$id)
names(d)[which(names(d)=="zone")]="harvestzone"
# had to rename because of the use of zone in the function led to duplicate column names

################## BY POPULATION ############################

zones <- c('Carib', 'Guianas', 'Brazil', 'Other') #List of zones to consider
#zones <- c('Carib', 'Guyana', 'Brazil') #List of zones to consider

data = d[d$pop=="Anchorage",]
sort(colSums(data[,14:17])) # ee how many positions in each zone

data = d[d$pop=="Kanuti",]
sort(colSums(data[,14:17])) # ee how many positions in each zone

data = d[d$pop=="Yellowknife",]
sort(colSums(data[,14:17])) # ee how many positions in each zone

data = d[d$pop=="Churchill",]
sort(colSums(data[,14:17])) # ee how many positions in each zone

data = d[d$pop=="James Bay",]
sort(colSums(data[,14:17])) # ee how many positions in each zone

data = d[d$pop=="Mingan",]
sort(colSums(data[,14:17])) # ee how many positions in each zone


# define model formula
lp <- ~ s(doy) # simple
lp <- ~ s(doy) + s(fid, bs = 're', by = dum) #formula
pdfname = paste("plots/",data$pop[1],"_random.pdf",sep="")

n.thresh = 2 # n.threshold refers to the number of data points. Only model zones with at least that many data points (they would be collapsed into an other category)
other.zone=FALSE

##Model specifications and set up
ns <- apply(data[, zones], 2, sum) #Number of locations in each zone not including 'Other'
zones <- names(ns[which(ns > n.thresh)]) #List of zones to model not including 'Other'

if(other.zone && n.thresh > 0) n.zone <- length(zones) + 1 else n.zone <- length(zones) #Number of zones to model
zone.code <- function(x){ #Function for coding zones (must include zero)
  if(any(x[zones] == 1)) which(x[zones] == 1) - 1 else ifelse(other.zone, n.zone - 1, NA)
}
zone <- unlist(apply(data, 1, zone.code)) #zone code
#if(other.zone && n.thresh > 0) zones <- c(zones, 'Other') #Add 'Other' zone to list

data.mn <- cbind(data, zone = zone, dum = 1) #Add zone code to dataset (also add dummy variable for predictions marginalized over random effect of fid)
data.mn <- data.mn[which(!is.na(data.mn$zone)), ] #Remove data for zones not considered

# Now the number threshold works so that this code can be put into a function
# Will want to delete the "other" parameter. That was used to group EEZs in the same geographical area that each had small numbers, like the Central Pacific islands

## FIT MODEL
mn.gam = gam(
  formula = c(list(reformulate(as.character(lp)[2], 'zone')), rep(list(lp), n.zone - 2)),
  data = data.mn,
  family = multinom(K = length(zones) - 1)) #Fit multinomial GAM

col.lkup = data.frame("zone" = c("Carib","Guianas","Brazil", "Other"), "col" = c("cyan3","black","green","gray"))
col.lkup$zone = as.character(col.lkup$zone)
col.lkup$col = as.character(col.lkup$col)

doy = 181:290

dnew <- data.frame(doy = doy) # Covariate data for prediction for simple model, without random effect
dnew <- data.frame(doy = 1:365, fid = data.mn$fid[1], dum=0) # Covariate data for prediction
p.hat <- predict(mn.gam, newdata = dnew, type='response', se.fit= TRUE) #Estimated probabilities

# Plot with CIs as polygons and model-estimated standard error
x = dnew$doy # define x axis
figmain = paste(data$pop[1], deparse(mn.gam$formula[[1]]))
#figmain = data$pop[1]
cols = col.lkup[match(zones,col.lkup[,1]),2] # Use color look-up table for each zone

pdf(pdfname, width = 11, height = 8)
plot(0, 0, type = 'n', xlim = c(150,290), ylim = c(0, 1), yaxs = 'i',
     xlab = 'Day of year', ylab = 'Estimated probability', main = figmain) #Set up plot
    for(i in 1:length(zones)) {
      ucl = p.hat$fit[, i] + p.hat$se.fit[, i]
      lcl = p.hat$fit[, i] - p.hat$se.fit[, i]
      i.for <- order(x)
      i.back <- order(x, decreasing = TRUE )
      x.polygon <- c( x[i.for] , x[i.back] )
      y.polygon <- c( ucl[i.for] , lcl[i.back] )
      polygon( x.polygon , y.polygon , col = adjustcolor(cols[i], alpha.f=0.07), border = NA )
      lines(x, p.hat$fit[, i], col = cols[i]) #Plot estimated probabilities
    }
legend(x = 'topright', legend = zones, lty = 1, col = cols, ncol = 4, cex = 0.8)
dev.off()

################## BY POPULATION: Only two predictions, inside or outside harvest zones ############################
## Collapse all harvest zones into one
## Does this still work with multinomial logistic regression? 
    # No, because you wouldn't expect the predictions across groups to add to one, only within groups. Each group has its own relationship with harvest zones
## So, just simple GAM (preferably with random effects)

## Create new column reclassifying harvest zone info as either present (1) or absent (0) in a zone
d$harvestzone.bn = d$harvestzone
d$harvestzone.bn[d$harvestzone.bn=="Other"]=0
d$harvestzone.bn[!d$harvestzone.bn==0]=1
d$harvestzone.bn = as.numeric(d$harvestzone.bn)

## Separate models for each population

############################
# YELLOWKNIFE (11 individuals)
data = d[d$pop=="Yellowknife",]
dum <- rep(1,length(data$id))

# GAM
m.yk = gam(harvestzone.bn ~s(doy), bs="cr", data=data)

# GAM + Random Effect (using dummy trick)
m.yk = gam(harvestzone.bn ~s(doy) + s(fid, bs = 're', by=dum), data=data)
dnew <- data.frame(doy = x, fid = data$fid[1], dum=0)
p.hat.yk <- predict(m.yk, newdata = dnew, type='response', se.fit= TRUE) #Estimated probabilities

############################
# ANCHORAGE (36 individuals)
data = d[d$pop=="Anchorage",]
library(dplyr)
count(data, id)
data[data$harvestzone.bn==1,c(1,12,15,16,17)] # see the data

dum <- rep(1,length(data$id))

# define model forumla
m.anc = gam(harvestzone.bn ~s(doy), data=data)

#Random Effect DUMMY
m.anc = gam(harvestzone.bn ~s(doy) + s(fid, bs = 're', by=dum), data=data)
dnew <- data.frame(doy = x, fid = data$fid[1], dum=0)
p.hat.anc <- predict(m.anc, newdata = dnew, type='response', se.fit= TRUE) #Estimated probabilities

################################
# CHURCHILL (19 individuals)
data = d[d$pop=="Churchill",]
count(data, id)
data[data$harvestzone.bn==1,c(1,12,15,16,17)] # see the data

dum <- rep(1,length(data$id))
# define model forumla
m.ch = gam(harvestzone.bn ~s(doy), data=data)

#Random Effect DUMMY
m.ch = gam(harvestzone.bn ~s(doy) + s(fid, bs = 're', by=dum), data=data)
dnew <- data.frame(doy = x, fid = data$fid[1], dum=0)
p.hat.ch <- predict(m.ch, newdata = dnew, type='response', se.fit= TRUE) #Estimated probabilities

# JAMES BAY (4 individuals, data only starting on 201 to 294 (before that, no harvest zone data))
data = d[d$pop=="James Bay",]
count(data, id)
dum <- rep(1,length(data$id))
# define model forumla
m.jb = gam(harvestzone.bn ~s(doy), bs="cr", data=data)

#Random Effect DUMMY
m.jb = gam(harvestzone.bn ~s(doy) + s(fid, bs = 're', by=dum), data=data)
dnew <- data.frame(doy = x, fid = data$fid[1], dum=0)
p.hat.jb <- predict(m.jb, newdata = dnew, type='response', se.fit= TRUE) #Estimated probabilities

####################################
# ANCHORAGE + KANUTI joined (44)
data = d[d$pop %in% c("Anchorage", "Kanuti"),]
count(data, id)
data[data$harvestzone.bn==1,c(1,12,15,16,17)] # see the data

dum <- rep(1,length(data$id))
#b1 <- gam(travel ~ s(Rail, bs="re", by=dum), data=Rail, method="REML")

# define model forumla
m.anc = gam(harvestzone.bn ~s(doy), data=data)

#Random Effect DUMMY
m.anc = gam(harvestzone.bn ~s(doy) + s(fid, bs = 're', by=dum), data=data)
dnew <- data.frame(doy = x, fid = data$fid[1], dum=0)
p.hat.anc <- predict(m.anc, newdata = dnew, type='response', se.fit= TRUE) #Estimated probabilities

#############################
# JAMES BAY + MINGAN joined (11)
data = d[d$pop %in% c("James Bay", "Mingan"),]
count(data, id)
data[data$harvestzone.bn==1,c(1,12,15,16,17)] # see the data

dum <- rep(1,length(data$id))
#b1 <- gam(travel ~ s(Rail, bs="re", by=dum), data=Rail, method="REML")

# define model forumla
m.jb = gam(harvestzone.bn ~s(doy), data=data)

#Random Effect DUMMY
m.anc = gam(harvestzone.bn ~s(doy) + s(fid, bs = 're', by=dum), data=data)
dnew <- data.frame(doy = x, fid = data$fid[1], dum=0)
p.hat.jb <- predict(m.jb, newdata = dnew, type='response', se.fit= TRUE) #Estimated probabilities


# # KANUTI: NO Harvest locations
# data = d[d$pop=="Kanuti",]
# 
# # define model forumla
# lp <- ~ s(doy) # simple
# #lp <- ~ s(doy) + s(fid, bs = 're', by = dum) #formula
# m.k = gam(harvestzone.bn ~s(doy), data=data)
# 
# # MINGAN: Only ONE individual
# data = d[d$pop=="Mingan",]
# 
# # define model forumla
# lp <- ~ s(doy) # simple
# #lp <- ~ s(doy) + s(fid, bs = 're', by = dum) #formula
# m.ming = gam(harvestzone.bn ~s(doy), bs="cr", data=data)

# Tried out Random Effect effect model predictions using the new "exclude" parameter (instead of dummy variable)
# didn't work properly, didn't take time to figure out why and went back to the tested dummy approach
# m.jb = gam(harvestzone.bn ~s(doy) + s(fid, bs = 're'), data=data)
# dnew=data.frame(doy = x, fid = data$fid[1], exclude="s(fid)") ## prediction with r.e using "exclude" parameter
# p.hat.jb <- predict(m.jb, newdata = dnew, type='response', se.fit= TRUE) #Estimated probabilities

doy = 181:290
dnew <- data.frame(doy = doy) # Covariate data for prediction for simple model, without random effect

# Plot with CIs as polygons and model-estimated standard error
x = doy # define x axis
figmain = "Any Harvest Zone, All populations: RANDOM effect of Individual"

zones = c('Alaska (Anchorage + Kanuti)', 'Yellowknife', 'Churchill', 'James Bay + Mingan')
col.lkup = data.frame("zone" = c('Alaska (Anchorage + Kanuti)', 'Yellowknife', 'Churchill', 'James Bay + Mingan'), "col" = c("cyan3","darkgoldenrod2","red","blue"))
col.lkup$zone = as.character(col.lkup$zone)
col.lkup$col = as.character(col.lkup$col)
cols = col.lkup[match(zones,col.lkup[,1]),2] # Use color look-up table for each zone


pdf(pdfname, width = 11, height = 8)
plot(0, 0, type = 'n', xlim = c(205,290), ylim = c(0, 1), yaxs = 'i',
     xlab = 'Day of year', ylab = 'Estimated probability of occurrence in any of 3 harvest', main = figmain) #Set up plot

  ucl = p.hat.jb$fit + p.hat.jb$se.fit
  lcl = p.hat.jb$fit - p.hat.jb$se.fit
  i.for <- order(x)
  i.back <- order(x, decreasing = TRUE )
  x.polygon <- c( x[i.for] , x[i.back] )
  y.polygon <- c( ucl[i.for] , lcl[i.back] )
  polygon( x.polygon , y.polygon , col = adjustcolor("blue", alpha.f=0.03), border = NA )
  lines(x, p.hat.jb$fit, col = "blue") #Plot estimated probabilities

  ucl = p.hat.yk$fit + p.hat.yk$se.fit
  lcl = p.hat.yk$fit - p.hat.yk$se.fit
  i.for <- order(x)
  i.back <- order(x, decreasing = TRUE )
  x.polygon <- c( x[i.for] , x[i.back] )
  y.polygon <- c( ucl[i.for] , lcl[i.back] )
  polygon( x.polygon , y.polygon , col = adjustcolor("darkgoldenrod2", alpha.f=0.07), border = NA )
  lines(x, p.hat.yk$fit, col = "darkgoldenrod2") #Plot estimated probabilities
  
  ucl = p.hat.anc$fit + p.hat.anc$se.fit
  lcl = p.hat.anc$fit - p.hat.anc$se.fit
  i.for <- order(x)
  i.back <- order(x, decreasing = TRUE )
  x.polygon <- c( x[i.for] , x[i.back] )
  y.polygon <- c( ucl[i.for] , lcl[i.back] )
  polygon( x.polygon , y.polygon , col = adjustcolor("cyan3", alpha.f=0.07), border = NA )
  lines(x, p.hat.anc$fit, col = "cyan3") #Plot estimated probabilities
  
  ucl = p.hat.ch$fit + p.hat.ch$se.fit
  lcl = p.hat.ch$fit - p.hat.ch$se.fit
  i.for <- order(x)
  i.back <- order(x, decreasing = TRUE )
  x.polygon <- c( x[i.for] , x[i.back] )
  y.polygon <- c( ucl[i.for] , lcl[i.back] )
  polygon( x.polygon , y.polygon , col = adjustcolor("red", alpha.f=0.07), border = NA )
  lines(x, p.hat.ch$fit, col = "red") #Plot estimated probabilities

legend(x = 'topright', legend = zones, lty = 1, col = cols, ncol = 2, cex = 0.8)
dev.off()

# ################## BY HARVEST ZONE ################################
# ## results could lead to misinterpretation due to small sample size
# 
# # create separate columns for each population
 x = dcast(d, as.numeric(rowid) ~ pop, length, value.var="pop")
 x[4625:4632,] #test matches original data
 d = cbind(d,x)
 rm(x)
# 
data = d[d$harvestzone=="Guyana",]
sort(colSums(data[,21:26])) # ee how many positions in each zone
# 
zones <- c('Anchorage', 'Yellowknife', 'Churchill', 'James Bay',"Mingan","Kanuti") #List of zones to consider
# 
# # define model forumla
 lp <- ~ s(doy) # simple
 lp <- ~ s(doy) + s(fid, bs = 're', by = dum) #formula
 pdfname = paste("plots/",data$harvestzone[1],"_random.pdf",sep="")
# 
n.thresh = 2 # n.threshold refers to the number of data points. Only model zones with at least that many data points (they would be collapsed into an other category)
other.zone=FALSE
# 
# ##Model specifications and set up
ns <- apply(data[, zones], 2, sum) #Number of locations in each zone not including 'Other'
zones <- names(ns[which(ns > n.thresh)]) #List of zones to model not including 'Other'
# 
if(other.zone && n.thresh > 0) n.zone <- length(zones) + 1 else n.zone <- length(zones) #Number of zones to model
zone.code <- function(x){ #Function for coding zones (must include zero)
if(any(x[zones] == 1)) which(x[zones] == 1) - 1 else ifelse(other.zone, n.zone - 1, NA)
 }
zone <- unlist(apply(data, 1, zone.code)) #zone code
if(other.zone && n.thresh > 0) zones <- c(zones, 'Other') #Add 'Other' zone to list
# 
data.mn <- cbind(data, zone = zone, dum = 1) #Add zone code to dataset (also add dummy variable for predictions marginalized over random effect of fid)
data.mn <- data.mn[which(!is.na(data.mn$zone)), ] #Remove data for zones not considered
# 
# # Now the number threshold works so that this code can be put into a function
# # Will want to delete the "other" parameter. That was used to group EEZs in the same geographical area that each had small numbers, like the Central Pacific islands
# 
# ## FIT MODEL
 mn.gam = gam(
   formula = c(list(reformulate(as.character(lp)[2], 'zone')), rep(list(lp), n.zone - 2)),
   data = data.mn,
   family = multinom(K = length(zones) - 1)) #Fit multinomial GAM
# 
col.lkup = data.frame("zone" = c('Anchorage', 'Yellowknife', 'Churchill', 'James Bay',"Mingan","Kanuti"), "col" = c("cyan3","darkgoldenrod2","red","blue","grey","green"))
col.lkup$zone = as.character(col.lkup$zone)
col.lkup$col = as.character(col.lkup$col)
# 
figmain = paste(data$harvestzone[1], deparse(mn.gam$formula[[1]]))
pdfname = paste("plots/",data$harvestzone[1],"_random.pdf",sep="")
# 
doy = 181:290
doy = min(data.mn$doy):max(data.mn$doy)
dnew <- data.frame(doy = doy) # Covariate data for prediction for simple model, without random effect
dnew <- data.frame(doy = 1:365, fid = data.mn$fid[1], dum=0) # Covariate data for prediction
p.hat <- predict(mn.gam, newdata = dnew, type='response', se.fit= TRUE) #Estimated probabilities
# 
# # Plot with CIs as polygons and model-estimated standard error
x = dnew$doy # define x axis
# 
cols = col.lkup[match(zones,col.lkup[,1]),2] # Use color look-up table for each zone
# 
pdf(pdfname, width = 11, height = 8)
plot(0, 0, type = 'n', xlim = c(150,290), ylim = c(0, 1), yaxs = 'i',
      xlab = 'Day of year', ylab = 'Estimated probability', main = figmain) #Set up plot
 for(i in 1:length(zones)) {
   ucl = p.hat$fit[, i] + p.hat$se.fit[, i]
   lcl = p.hat$fit[, i] - p.hat$se.fit[, i]
   i.for <- order(x)
   i.back <- order(x, decreasing = TRUE )
   x.polygon <- c( x[i.for] , x[i.back] )
   y.polygon <- c( ucl[i.for] , lcl[i.back] )
  polygon( x.polygon , y.polygon , col = adjustcolor(cols[i], alpha.f=0.07), border = NA )
   lines(x, p.hat$fit[, i], col = cols[i]) #Plot estimated probabilities
 }
 legend(x = 'topright', legend = zones, lty = 1, col = cols, ncol = 4, cex = 0.8)
 dev.off()
# 
# 
