#################################################################################################
# Laura McDuffie, University of Alaska, USFWS - Lesser Yellowlegs
# Code to support: Differential harvest exposure of Lesser Yellowlegs during autumn migration
# 
# Authors: Autumn-Lynn Harrison, HarrisonAL@si.edu, Smithsonian Migratory Bird center
#
# Step 3a: Use Generalized additive models to predict probability of occurrence in any zone

#  -- Populations modeled separately
#  -- All harvest zones grouped together
#  -- Becomes a simple binomial model: in harvest zone, or outside harvest zone

#################################################################################################

# load libraries from config file
source("0-config.r")

# Specify time frame for model predictions (Day of Year x-axis in GAM plots)
doy = 181:290 # June 30 - October 17 

# load data (output of Step 2). Chose set of Narrow or Broad below
 
# NARROW Zones Data set and variable names
 load("results/02_fG_LEYE_rw_ZonesAssigned_Narrow.RData")
 figmain = "Any *Narrow* Harvest Zone, Simple Binomial GAM, No Random Effect"
 pdfname = "plots/PopsInAnyNarrowZone_GAM.pdf"
 figmainR = "Any *Narrow* Harvest Zone, Random Effect Individual"
 pdfnameR = "plots/PopsInAnyNarrowZone_GAM_RandomEffect.pdf"
 figmainAR = "Any *Narrow* Harvest Zone, Autocorrelation"
 pdfnameAR = "plots/PopsInAnyNarrowZone_GAMM_AR1byID.pdf"

 theme_set(theme_bw())
 
# BROAD Zones Data set and variable names
# load("results/02_fG_LEYE_rw_ZonesAssigned_Broad.RData")
# figmain = "Any Broad Harvest Zone, Simple Binomial GAM, No Random Effect"
# pdfname = "plots/PopsInAnyBroadZone_GAM.pdf"
# figmainR = "Any Broad Harvest Zone, Random Effect Individual"
# pdfnameR = "plots/PopsInAnyBroadZone_GAM_RandomEffect.pdf.pdf"

d$fid = factor(d$id)
names(d)[which(names(d)=="zone")]="harvestzone"
# had to rename because of the use of zone in the function led to duplicate column names

# Populations
# table(d$pop): Anchorage (4091), Churchill (1926), James Bay (310), Kanuti (640), Mingan (690), Yellowknife (1158)

## Create new column reclassifying harvest zone info as either present (1) or absent (0) in a zone
d$harvestzone.bn = d$harvestzone
d$harvestzone.bn[d$harvestzone.bn=="Other"]=0
d$harvestzone.bn[!d$harvestzone.bn==0]=1
d$harvestzone.bn = as.numeric(d$harvestzone.bn)

## Separate models for each population

######################################################################################
# Option 1a. BINOMIAL GAM for each Population. NO RANDOM EFFECT
# Streamlined version of Option 1b using factor levels in single model...by-variable smooths
# Presence or absence in any exposure zone (binomal)
# Predicted by day of year (continuous)
######################################################################################

# Uses "by=pop" to create a separate smoother for each population. 
# Streamlined approach to estimating smooths for each factor level

data = d
data$pop[which(data$pop=="Kanuti")]="Anchorage"
data$pop[which(data$pop=="Mingan")]="James Bay"

data$pop <- as.factor(data$pop) # must convert population (character) to factor before fitting gam.
str(data)

m = gam(harvestzone.bn ~ s(doy, by=pop) + pop, data=data, family = binomial("logit")) #One smoother per population, no random effects
dnew <- data.frame(doy=rep(doy,4), pop=c(rep("Anchorage",length(doy)),rep("Churchill",length(doy)),rep("Yellowknife",length(doy)),rep("James Bay",length(doy))))

df2 = predict(m, type="response", se.fit=TRUE, newdata = dnew)
df2 = cbind(dnew, response = df2$fit, lwr = df2$fit-2*df2$se.fit, upr = df2$fit+2*df2$se.fit)

pdf("plots/PopsInAnyNarrowZone_GAM_by.pdf", width = 11, height = 8)        
ggplot() +
  geom_ribbon(data = df2, mapping=aes(x=doy, ymin=lwr, ymax=upr, fill=pop), alpha=0.25) +
  geom_line(data = df2, mapping=aes(x=doy, y=response, col=pop)) + 
  ylim(0, 1) + xlim(205,290)
dev.off()

# https://fromthebottomoftheheap.net/2017/10/10/difference-splines-i/
# With by-variable smooths each of the separate smooths is subject to identifiability constraints, which effectively centres each smooth around zero effect. 

# This means that the mean probability of each population is not accounted for by the smooths. To rectify this the population code is added as a parametric term to the model, along with the smooths.

######################################################################################
# Option 1b. BINOMIAL GAM. Modeled separately for each Population. NO RANDOM EFFECT
# Separate model for each population
# Presence or absence in any exposure zone (binomal)
# Predicted by day of year (continuous)
######################################################################################

# Separate model for each population. 
# Yields slightly different results than above and may be easier to include random effects of individual

dnew <- data.frame(doy = doy)

############################
# YELLOWKNIFE (11 individuals)
data = d[d$pop=="Yellowknife",]

# GAM
m.yk = gam(harvestzone.bn ~s(doy), bs="cr", family = binomial("logit"), data=data)
p.hat.yk <- predict(m.yk, newdata = dnew, type='response', se.fit= TRUE) #Estimated probabilities

############################
# ANCHORAGE (34 individuals)
data = d[d$pop=="Anchorage",]

library(dplyr)
count(data, id)

# GAM
m.anc = gam(harvestzone.bn ~s(doy), family = binomial("logit"), data=data) # define model formula
p.hat.anc <- predict(m.anc, newdata = dnew, type='response', se.fit= TRUE) #Estimated probabilities

############################
# CHURCHILL (19 individuals)
data = d[d$pop=="Churchill",]
count(data, id)


#GAM
m.ch = gam(harvestzone.bn ~s(doy), family=binomial("logit"), data=data)
p.hat.ch <- predict(m.ch, newdata = dnew, type='response', se.fit= TRUE) #Estimated probabilities

############################
# JAMES BAY (4 individuals, data only starting on 201 to 294 (before that, no harvest zone data))
#data = d[d$pop=="James Bay",]
#count(data, id)

#GAM
#m.jb = gam(harvestzone.bn ~s(doy), bs="cr", family=binomial("logit"), data=data)
#p.hat.jb <- predict(m.jb, newdata = dnew, type='response', se.fit= TRUE) #Estimated probabilities

############################
# ANCHORAGE + KANUTI joined (40 individuals)
# # KANUTI: NO Harvest locations
data = d[d$pop=="Kanuti",]

data = d[d$pop %in% c("Anchorage", "Kanuti"),]
count(data, id)

# GAM 
m.anc.k = gam(harvestzone.bn ~s(doy), family=binomial("logit"), data=data) # define model forumla
p.hat.anc.k <- predict(m.anc.k, newdata = dnew, type='response', se.fit= TRUE) #Estimated probabilities

############################
# JAMES BAY + MINGAN joined (10 individuals)
data = d[d$pop=="Mingan",]

data = d[d$pop %in% c("James Bay", "Mingan"),]
count(data, id)

# GAM
m.jb.min = gam(harvestzone.bn ~s(doy), family=binomial("logit"), data=data)
p.hat.jb.min <- predict(m.jb.min, newdata = dnew, type='response', se.fit= TRUE) #Estimated probabilities

############################
# PLOTTING PREDICTIONS
# Plot with CIs as polygons and model-estimated standard error

# Set variables
x = doy # define x axis

# Set colors for legend
zones = c('Alaska (Anchorage + Kanuti)', 'Yellowknife', 'Churchill', 'James Bay + Mingan')
col.lkup = data.frame("zone" = c('Alaska (Anchorage + Kanuti)', 'Yellowknife', 'Churchill', 'James Bay + Mingan'), "col" = c("cyan3","darkgoldenrod2","red","blue"))
col.lkup$zone = as.character(col.lkup$zone)
col.lkup$col = as.character(col.lkup$col)
cols = col.lkup[match(zones,col.lkup[,1]),2] # Use color look-up table for each zone

# Plot and save out as pdf. 
# Add each population one by one (Already had this code, but could have done more efficiently similar to ggplot code above)

pdf(pdfname, width = 11, height = 8)
  plot(0, 0, type = 'n', xlim = c(205,290), ylim = c(0, 1), yaxs = 'i',
     xlab = 'Day of year', ylab = 'Estimated probability of occurrence in any of 3 harvest', main = figmain) #Set up plot

  # James Bay + Mingan
  m = p.hat.jb.min
  ucl = m$fit + m$se.fit
  lcl = m$fit - m$se.fit
  i.for <- order(x)
  i.back <- order(x, decreasing = TRUE )
  x.polygon <- c( x[i.for] , x[i.back] )
  y.polygon <- c( ucl[i.for] , lcl[i.back] )
  polygon( x.polygon , y.polygon , col = adjustcolor("blue", alpha.f=0.03), border = NA )
  lines(x, m$fit, col = "blue") #Plot estimated probabilities
  
  # Yellowknife
  m = p.hat.yk
  ucl = m$fit + m$se.fit
  lcl = m$fit - m$se.fit
  i.for <- order(x)
  i.back <- order(x, decreasing = TRUE )
  x.polygon <- c( x[i.for] , x[i.back] )
  y.polygon <- c( ucl[i.for] , lcl[i.back] )
  polygon( x.polygon , y.polygon , col = adjustcolor("darkgoldenrod2", alpha.f=0.07), border = NA )
  lines(x, m$fit, col = "darkgoldenrod2") #Plot estimated probabilities
  
  # Anchorage + Kanuti
  m = p.hat.anc.k
  ucl = m$fit + m$se.fit
  lcl = m$fit - m$se.fit
  i.for <- order(x)
  i.back <- order(x, decreasing = TRUE )
  x.polygon <- c( x[i.for] , x[i.back] )
  y.polygon <- c( ucl[i.for] , lcl[i.back] )
  polygon( x.polygon , y.polygon , col = adjustcolor("cyan3", alpha.f=0.07), border = NA )
  lines(x, m$fit, col = "cyan3") #Plot estimated probabilities
  
  # Churchill
  m = p.hat.ch
  ucl = m$fit + m$se.fit
  lcl = m$fit - m$se.fit
  i.for <- order(x)
  i.back <- order(x, decreasing = TRUE )
  x.polygon <- c( x[i.for] , x[i.back] )
  y.polygon <- c( ucl[i.for] , lcl[i.back] )
  polygon( x.polygon , y.polygon , col = adjustcolor("red", alpha.f=0.07), border = NA )
  lines(x, p.hat.ch$fit, col = "red") #Plot estimated probabilities

legend(x = 'topright', legend = zones, lty = 1, col = cols, ncol = 2, cex = 0.8)
dev.off()


######################################################################################
# Option 2a. MIXED MODEL, RANDOM EFFECT OF INDIVIDUAL 
# Streamlined version of Option 2b using factor levels in single model...by-variable smooths
# Adds a smooth term with a random effects basis for Individual ID (this is an intercept term)
# Presence or absence in any exposure zone (binomal)
# Predicted by day of year (continuous)
######################################################################################

# Uses "by=pop" to create a separate smoother for each population. 
# Streamlined approach to estimating smooths for each factor level
# Add intercept effect of individual (we are not interested in individual relationships, therefore do not need separate slopes)

data = d
data$pop[which(data$pop=="Kanuti")]="Anchorage"
data$pop[which(data$pop=="Mingan")]="James Bay"

m = gam(harvestzone.bn ~ s(doy, by=pop) + pop + s(fid,bs="re"), data=data, family = binomial) #One smoother per population, no random effects
dnew <- data.frame(doy=rep(doy,4), pop=c(rep("Anchorage",length(doy)),rep("Churchill",length(doy)),rep("Yellowknife",length(doy)),rep("James Bay",length(doy))), fid=data$fid[1])

df2 = predict(m, type="response", newdata = dnew, se.fit=TRUE, exclude="s(fid)")
df2 = cbind(dnew, response = df2$fit, lwr = df2$fit-2*df2$se.fit, upr = df2$fit+2*df2$se.fit)

pdf("plots/PopsInAnyNarrowZone_GAM_by_RandomEffect.pdf", width = 11, height = 8)        
ggplot() +
  geom_ribbon(data = df2, mapping=aes(x=doy, ymin=lwr, ymax=upr, fill=pop), alpha=0.25) +
  geom_line(data = df2, mapping=aes(x=doy, y=response, col=pop)) + 
  ylim(0, 1) + xlim(205,290)
dev.off()

# Something funky with CIs

######################################################################################
# Option 2b. MIXED MODEL, RANDOM EFFECT OF INDIVIDUAL 
# Presence or absence in any exposure zone (binomal)
# Predicted by day of year (continuous)
# Random intercept effect of individual
######################################################################################
# gamm version of this model properly constrains the CIs between 0 and 1. 
# gam version does not. If want to take this approach, will need to simulate confidence intervals
# as was done in Harrison 2018

############################
# YELLOWKNIFE (11 individuals)
data = d[d$pop=="Yellowknife",]

# m.yk = gam(harvestzone.bn ~s(doy) + s(fid, bs = 're'), family=binomial("logit"), data=data)
# dnew <- data.frame(doy = doy, fid = data$fid[1])
# p.hat.yk <- predict(m.yk, newdata = dnew, type='response', se.fit= TRUE, exclude="s(fid)") #mean response

m.yk <- gamm(harvestzone.bn ~s(doy), random=list(fid=~1), data=data, family=binomial("logit")) # Random intercept for individual
dnew <- data.frame(doy = doy, fid = data$fid[1])
p.hat.yk <- predict(m.yk$gam, newdata = dnew, type='response', se.fit= TRUE, exclude="s(fid)") #mean response 
plot(p.hat.yk$fit)

############################
# CHURCHILL (19 individuals)
data = d[d$pop=="Churchill",]

m.ch <- gamm(harvestzone.bn ~s(doy), random=list(fid=~1), data=data, family=binomial("logit")) # Random intercept for individual
dnew <- data.frame(doy = doy, fid = data$fid[1])
p.hat.ch <- predict(m.ch$gam, newdata = dnew, type='response', se.fit= TRUE, exclude="s(fid)") #mean response 
plot(p.hat.ch$fit)

# m.ch = gam(harvestzone.bn ~s(doy) + s(fid, bs = 're'), family=binomial("logit"), data=data)
# dnew <- data.frame(doy = doy, fid = data$fid[1])
# p.hat.ch <- predict(m.ch, newdata = dnew, type='response', se.fit= TRUE, exclude="s(fid)") #mean response

############################
# ANCHORAGE + KANUTI joined
data = d[d$pop %in% c("Anchorage", "Kanuti"),]

m.anc.k = gam(harvestzone.bn ~s(doy) + s(fid, bs = 're'), family=binomial("logit"), data=data)
dnew <- data.frame(doy = doy, fid = data$fid[1])
p.hat.anc.k <- predict(m.anc.k, newdata = dnew, type='response', se.fit= TRUE, exclude="s(fid)") #mean response

# Did not converge
# m.anc.k <- gamm(harvestzone.bn ~s(doy), random=list(fid=~1), data=data, family=binomial("logit"), niterPQL = 500) # Random intercept for individual
# dnew <- data.frame(doy = doy, fid = data$fid[1])
# p.hat.anc.k <- predict(m.anc.k$gam, newdata = dnew, type='response', se.fit= TRUE, exclude="s(fid)") #mean response 
#plot(p.hat.anc.k$fit)

############################
# JAMES BAY + MINGAN joined
data = d[d$pop %in% c("James Bay", "Mingan"),]

# m.jb.min = gam(harvestzone.bn ~s(doy) + s(fid, bs = 're'), family=binomial("logit"), data=data)
# dnew <- data.frame(doy = doy, fid = data$fid[1])
# p.hat.jb.min <- predict(m.jb.min, newdata = dnew, type='response', se.fit= TRUE, exclude="s(fid)") #mean response 

m.jb.min <- gamm(harvestzone.bn ~s(doy), random=list(fid=~1), data=data, family=binomial("logit")) # Random intercept for individual
dnew <- data.frame(doy = doy, fid = data$fid[1])
p.hat.jb.min <- predict(m.jb.min$gam, newdata = dnew, type='response', se.fit= TRUE, exclude="s(fid)") #mean response 
plot(p.hat.jb.min$fit)

############################
# JAMES BAY (4 individuals, data only starting on 201 to 294 (before that, no harvest zone data))
data = d[d$pop=="James Bay",]

m.jb = gam(harvestzone.bn ~s(doy) + s(fid, bs = 're'), family=binomial("logit"), data=data)
dnew <- data.frame(doy = doy, fid = data$fid[1])
p.hat.jb <- predict(m.jb, newdata = dnew, type='response', se.fit= TRUE, exclude="s(fid)") #mean response

############################
# ANCHORAGE (34 individuals)
# data = d[d$pop=="Anchorage",]

# m.anc = gam(harvestzone.bn ~s(doy) + s(fid, bs = 're'), family=binomial("logit"), data=data)
# dnew <- data.frame(doy = doy, fid = data$fid[1])
# p.hat.anc <- predict(m.anc, newdata = dnew, type='response', se.fit= TRUE, exclude="s(fid)") #mean responses

############################
# PLOTTING PREDICTIONS
# Plot with CIs as polygons and model-estimated standard error

# Set variables
x = doy # define x axis

# Set colors for legend
zones = c('Alaska (Anchorage + Kanuti)', 'Yellowknife', 'Churchill', 'James Bay + Mingan')
col.lkup = data.frame("zone" = c('Alaska (Anchorage + Kanuti)', 'Yellowknife', 'Churchill', 'James Bay + Mingan'), "col" = c("cyan3","darkgoldenrod2","red","blue"))
col.lkup$zone = as.character(col.lkup$zone)
col.lkup$col = as.character(col.lkup$col)
cols = col.lkup[match(zones,col.lkup[,1]),2] # Use color look-up table for each zone

# Plot and save out as pdf. 
# Add each population one by one (Prob could have done more efficiently with a list of model results but I like exploring the colors and transparencies for each population manually)

pdf(pdfnameR, width = 11, height = 8)
plot(0, 0, type = 'n', xlim = c(205,290), ylim = c(0, 1), yaxs = 'i',
     xlab = 'Day of year', ylab = 'Estimated probability of occurrence in any of 3 harvest', main = figmainR) #Set up plot

# James Bay + Mingan
m = p.hat.jb.min
ucl = m$fit + m$se.fit
lcl = m$fit - m$se.fit
i.for <- order(x)
i.back <- order(x, decreasing = TRUE )
x.polygon <- c( x[i.for] , x[i.back] )
y.polygon <- c( ucl[i.for] , lcl[i.back] )
polygon( x.polygon , y.polygon , col = adjustcolor("blue", alpha.f=0.03), border = NA )
lines(x, m$fit, col = "blue") #Plot estimated probabilities

# Yellowknife
m = p.hat.yk
ucl = m$fit + m$se.fit
lcl = m$fit - m$se.fit
i.for <- order(x)
i.back <- order(x, decreasing = TRUE )
x.polygon <- c( x[i.for] , x[i.back] )
y.polygon <- c( ucl[i.for] , lcl[i.back] )
polygon( x.polygon , y.polygon , col = adjustcolor("darkgoldenrod2", alpha.f=0.07), border = NA )
lines(x, m$fit, col = "darkgoldenrod2") #Plot estimated probabilities

# Anchorage + Kanuti
m = p.hat.anc.k
ucl = m$fit + m$se.fit
lcl = m$fit - m$se.fit
i.for <- order(x)
i.back <- order(x, decreasing = TRUE )
x.polygon <- c( x[i.for] , x[i.back] )
y.polygon <- c( ucl[i.for] , lcl[i.back] )
polygon( x.polygon , y.polygon , col = adjustcolor("cyan3", alpha.f=0.07), border = NA )
lines(x, m$fit, col = "cyan3") #Plot estimated probabilities

# Churchill
m = p.hat.ch
ucl = m$fit + m$se.fit
lcl = m$fit - m$se.fit
i.for <- order(x)
i.back <- order(x, decreasing = TRUE )
x.polygon <- c( x[i.for] , x[i.back] )
y.polygon <- c( ucl[i.for] , lcl[i.back] )
polygon( x.polygon , y.polygon , col = adjustcolor("red", alpha.f=0.07), border = NA )
lines(x, p.hat.ch$fit, col = "red") #Plot estimated probabilities

legend(x = "top",legend = zones, lty = 1, col = cols, ncol = 4, cex = 0.8, bty = "n")
dev.off()

######################################################################################
# MIXED MODEL (GAMM), AUTOCORRELATION STRUCTURE
# Presence or absence in any exposure zone (binomal)
# Predicted by day of year (continuous)
# Autocorrelation within ID
######################################################################################

############################
# YELLOWKNIFE (11 individuals)
data = d[d$pop=="Yellowknife",]

#m.yk <- gamm(harvestzone.bn ~s(doy), family=binomial("logit"), data=data, correlation=corAR1()) # basic autocorrelaiton
#p.hat.yk <- predict(m.yk$gam, newdata = dnew, type='response', se.fit= TRUE, exclude="s(fid)") #mean response 
#plot(p.hat.yk$fit)

m.yk <- gamm(harvestzone.bn ~s(doy), family=binomial("logit"), data=data, correlation=corAR1(form=~1|fid))
dnew <- data.frame(doy = doy, fid = data$fid[1])
p.hat.yk <- predict(m.yk$gam, newdata = dnew, type='response', se.fit= TRUE, exclude="s(fid)") #mean response 
#plot(p.hat.yk$fit)
#lines(p.hat.yk$se)

############################
# CHURCHILL (19 individuals)
data = d[d$pop=="Churchill",]

#Autocorrelation
m.ch <- gamm(harvestzone.bn ~s(doy), family=binomial("logit"), data=data, correlation=corAR1(), method="ML", niterPQL=50)
dnew <- data.frame(doy = doy, fid = data$fid[1])
p.hat.ch <- predict(m.ch$gam, newdata = dnew, type='response', se.fit= TRUE, exclude="s(fid)") #mean response 

# GAMM random intercept? These two are the same, correct?
m.ch <- gamm(harvestzone.bn ~s(doy), random=list(fid=~1), data=data, family=binomial("logit")) # Random intercept for individual
m.ch <- gamm(harvestzone.bn ~s(doy) + s(fid, bs="re"), family=binomial("logit"), data=data )

# did not converge
m.ch <- gamm(harvestzone.bn ~s(doy), random=list(fid=~1+doy), data=data, family=binomial("logit"), niterPQL=100) # Random intercept + slope
m.ch <- gamm(harvestzone.bn ~s(doy) + s(doy,fid, bs="re"), family=binomial("logit"), data=data ) # converged
m.ch <- gamm(harvestzone.bn ~s(doy) + s(fid, bs="re") + s(doy,fid, bs="re"), family=binomial("logit"), data=data, niterPQL=100 ) # converged

m.ch <- gamm(harvestzone.bn ~s(doy), random=list(fid=~1), data=data, family=binomial("logit")) # Random intercept for individual
dnew <- data.frame(doy = doy, fid = data$fid[1])
p.hat.ch <- predict(m.ch$gam, newdata = dnew, type='response', se.fit= TRUE, exclude="s(fid)") #mean response 
plot(p.hat.ch$fit)


############################
# ANCHORAGE + KANUTI joined
data = d[d$pop %in% c("Anchorage", "Kanuti"),]

#Random Effect DUMMY
m.anc.k <- gamm(harvestzone.bn ~s(doy), family=binomial("logit"), data=data, correlation=corAR1(form=~1|fid))
dnew <- data.frame(doy = doy, fid = data$fid[1])
p.hat.anc.k <- predict(m.anc.k$gam, newdata = dnew, type='response', se.fit= TRUE, exclude="s(fid)") #mean response 

############################
# JAMES BAY + MINGAN joined
data = d[d$pop %in% c("James Bay", "Mingan"),]

#Random Effect DUMMY
m.jb.min = gam(harvestzone.bn ~s(doy) + s(fid, bs = 're'), family=binomial("logit"), data=data)
dnew <- data.frame(doy = doy, fid = data$fid[1])
p.hat.jb.min <- predict(m.jb.min, newdata = dnew, type='response', se.fit= TRUE, exclude="s(fid)") #mean response 

m.jb.min <- gamm(harvestzone.bn ~s(doy), random=list(fid=~1), data=data, family=binomial("logit"))
m.jb.min <- gamm(harvestzone.bn ~s(doy) + s(fid, bs="re"), family=binomial("logit"), data=data)
m.jb.min <- gamm(harvestzone.bn ~s(doy) + s(fid, bs="re"), family=binomial("logit"), data=data, correlation=corAR1())
#m.jb.min <- gamm(harvestzone.bn ~s(doy), family=binomial("logit"), data=data, correlation=corAR1(form=~1|fid))
dnew <- data.frame(doy = doy, fid = data$fid[1])
p.hat.jb.min <- predict(m.jb.min$gam, newdata = dnew, type='response', se.fit= TRUE, exclude="s(fid)") #mean response 

#Random Effect DUMMY with GAM
m.jb.min = gam(harvestzone.bn ~s(doy) + s(fid, bs = 're'), family=binomial("logit"), data=data)



############################
# PLOTTING PREDICTIONS
# Plot with CIs as polygons and model-estimated standard error

# Set variables
x = doy # define x axis

# Set colors for legend
zones = c('Alaska (Anchorage + Kanuti)', 'Yellowknife', 'Churchill', 'James Bay + Mingan')
col.lkup = data.frame("zone" = c('Alaska (Anchorage + Kanuti)', 'Yellowknife', 'Churchill', 'James Bay + Mingan'), "col" = c("cyan3","darkgoldenrod2","red","blue"))
col.lkup$zone = as.character(col.lkup$zone)
col.lkup$col = as.character(col.lkup$col)
cols = col.lkup[match(zones,col.lkup[,1]),2] # Use color look-up table for each zone

# Plot and save out as pdf. 
# Add each population one by one (Prob could have done more efficiently with a list of model results but I like exploring the colors and transparencies for each population manually)

pdf(pdfnameAR, width = 11, height = 8)
plot(0, 0, type = 'n', xlim = c(205,290), ylim = c(0, 1), yaxs = 'i',
     xlab = 'Day of year', ylab = 'Estimated probability of occurrence in any of 3 harvest', main = figmainAR) #Set up plot

# James Bay + Mingan
m = p.hat.jb.min
ucl = m$fit + m$se.fit
lcl = m$fit - m$se.fit
i.for <- order(x)
i.back <- order(x, decreasing = TRUE )
x.polygon <- c( x[i.for] , x[i.back] )
y.polygon <- c( ucl[i.for] , lcl[i.back] )
polygon( x.polygon , y.polygon , col = adjustcolor("blue", alpha.f=0.03), border = NA )
lines(x, m$fit, col = "blue") #Plot estimated probabilities

# Yellowknife
m = p.hat.yk
ucl = m$fit + m$se.fit
lcl = m$fit - m$se.fit
i.for <- order(x)
i.back <- order(x, decreasing = TRUE )
x.polygon <- c( x[i.for] , x[i.back] )
y.polygon <- c( ucl[i.for] , lcl[i.back] )
polygon( x.polygon , y.polygon , col = adjustcolor("darkgoldenrod2", alpha.f=0.07), border = NA )
lines(x, m$fit, col = "darkgoldenrod2") #Plot estimated probabilities

# Anchorage + Kanuti
m = p.hat.anc.k
ucl = m$fit + m$se.fit
lcl = m$fit - m$se.fit
i.for <- order(x)
i.back <- order(x, decreasing = TRUE )
x.polygon <- c( x[i.for] , x[i.back] )
y.polygon <- c( ucl[i.for] , lcl[i.back] )
polygon( x.polygon , y.polygon , col = adjustcolor("cyan3", alpha.f=0.07), border = NA )
lines(x, m$fit, col = "cyan3") #Plot estimated probabilities

# Churchill
m = p.hat.ch
ucl = m$fit + m$se.fit
lcl = m$fit - m$se.fit
i.for <- order(x)
i.back <- order(x, decreasing = TRUE )
x.polygon <- c( x[i.for] , x[i.back] )
y.polygon <- c( ucl[i.for] , lcl[i.back] )
polygon( x.polygon , y.polygon , col = adjustcolor("red", alpha.f=0.07), border = NA )
lines(x, p.hat.ch$fit, col = "red") #Plot estimated probabilities

legend(x = 'topright', legend = zones, lty = 1, col = cols, ncol = 2, cex = 0.8)
dev.off()


