#################################################################################################
# Laura McDuffie, University of Alaska Anchorage, USFWS - Lesser Yellowlegs
# Code to support: Differential harvest exposure of Lesser Yellowlegs during autumn migration
# 
# Authors: Autumn-Lynn Harrison, HarrisonAL@si.edu, Smithsonian Migratory Bird center
#
# Step 3b.1: Use Binomial models for each Population/Zone pair to predict probability of occurrence in harvest zones
#################################################################################################

# load libraries from config file
source("0-config.r")

# load data (output of Step 2)
load("results/02_fG_LEYE_rw_ZonesAssigned_Narrow.RData")

################## Data Prep ############################

d$fid = factor(d$id)

# Collapse Kanuti and Mingan into larger groupings
d$pop[which(d$pop=="Kanuti")]="Anchorage"
d$pop[which(d$pop=="Mingan")]="James Bay"

pops = c("Yellowknife","Churchill", "Anchorage", "James Bay")

# Populations
# table(d$pop): Anchorage (4731), Churchill (1926), James Bay (1000), Yellowknife (1158)

################## BY POPULATION ############################

# Choose one of these sets (both populations only have positions in Guianas, Caribbean, Other)
data = d[d$pop=="Yellowknife",]
pdfname = "plots/Yellowknife_Binomials_RandomEffect.pdf"

data = d[d$pop=="Anchorage",]
pdfname = "plots/Anchorage_Binomials_RandomEffect.pdf"


doy = 181:290
zones <- c('Other', 'Guianas', 'Carib','Brazil' ) #List of zones to consider
sort(colSums(data[,zones])) # how many positions in each zone
#Carib, Guyana, Other

dnew <- data.frame(doy = doy, fid = data$fid[1])

m.Other = gam(Other ~ s(doy) + s(fid, bs="re"), data=data, family = binomial("logit")) 
p.Other = predict(m.Other, type="response", se.fit=TRUE, newdata = dnew, exclude="s(fid)")

m.Guianas = gam(Guianas ~ s(doy) + s(fid, bs="re"), data=data, family = binomial("logit")) #One smoother per zone, no random effects
p.Guianas = predict(m.Guianas, type="response", se.fit=TRUE, newdata = dnew, exclude="s(fid)")

m.Carib = gam(Carib ~ s(doy) + s(fid, bs="re"), data=data, family = binomial("logit")) #One smoother per zone, no random effects
p.Carib = predict(m.Carib, type="response", se.fit=TRUE, newdata = dnew, exclude="s(fid)")

############################
# PLOTTING PREDICTIONS
# Plot with CIs as polygons and model-estimated standard error

# Set variables
x = doy # define x axis

col.lkup = data.frame("zone" = c("Carib","Guianas","Brazil", "Other"), "col" = c("cyan3","black","green","gray"))
col.lkup$zone = as.character(col.lkup$zone)
col.lkup$col = as.character(col.lkup$col)

x = dnew$doy # define x axis
figmain = data$pop[1]
cols = col.lkup[match(zones,col.lkup[,1]),2] # Use color look-up table for each zone

# Plot and save out as pdf. 
# Add each population one by one (Already had this code, but could have done more efficiently

pdf(pdfname, width = 11, height = 8)
  plot(0, 0, type = 'n', xlim = c(205,290), ylim = c(0, 1), yaxs = 'i',
     xlab = 'Day of year', ylab = 'Estimated probability of occurrence in any of 3 harvest', main = figmain) #Set up plot

  # Other
  m = p.Other
  ucl = m$fit + m$se.fit
  lcl = m$fit - m$se.fit
  i.for <- order(x)
  i.back <- order(x, decreasing = TRUE )
  x.polygon <- c( x[i.for] , x[i.back] )
  y.polygon <- c( ucl[i.for] , lcl[i.back] )
  polygon( x.polygon , y.polygon , col = adjustcolor("gray", alpha.f=0.1), border = NA )
  lines(x, m$fit, col = "gray") #Plot estimated probabilities

  # Carib
  m = p.Carib
  ucl = m$fit + m$se.fit
  lcl = m$fit - m$se.fit
  i.for <- order(x)
  i.back <- order(x, decreasing = TRUE )
  x.polygon <- c( x[i.for] , x[i.back] )
  y.polygon <- c( ucl[i.for] , lcl[i.back] )
  polygon( x.polygon , y.polygon , col = adjustcolor("cyan3", alpha.f=0.03), border = NA )
  lines(x, m$fit, col = "cyan3") #Plot estimated probabilities

  # Guianas
  m = p.Guianas
  ucl = m$fit + m$se.fit
  lcl = m$fit - m$se.fit
  i.for <- order(x)
  i.back <- order(x, decreasing = TRUE )
  x.polygon <- c( x[i.for] , x[i.back] )
  y.polygon <- c( ucl[i.for] , lcl[i.back] )
  polygon( x.polygon , y.polygon , col = adjustcolor("black", alpha.f=0.03), border = NA )
  lines(x, m$fit, col = "black") #Plot estimated probabilities

  legend(x = "topright",legend = zones, lty = 1, col = cols, ncol = 2, cex = 0.8, inset=c(0,-0.2), xpd=TRUE, bty = "n")
  
dev.off()  

####################################################
# Choose one of these sets (both populations have positions in all 4 zones)

data = d[d$pop=="Churchill",]
pdfname = "plots/Churchill_Binomials_RandomEffect.pdf"

data = d[d$pop=="James Bay",]
pdfname = "plots/JamesBayMingan_Binomials_RandomEffect.pdf"## Does not converge

doy = 181:290
zones <- c('Other', 'Guianas', 'Carib','Brazil' ) #List of zones to consider
sort(colSums(data[,zones])) # how many positions in each zone
#Carib, Guianas, Other

dnew <- data.frame(doy = doy, fid = data$fid[1])

m.Other = gam(Other ~ s(doy) + s(fid, bs="re"), data=data, family = binomial("logit")) 
p.Other = predict(m.Other, type="response", se.fit=TRUE, newdata = dnew, exclude="s(fid)")

m.Guianas = gam(Guianas ~ s(doy) + s(fid, bs="re"), data=data, family = binomial("logit")) #One smoother per zone, no random effects
p.Guianas = predict(m.Guianas, type="response", se.fit=TRUE, newdata = dnew, exclude="s(fid)")

m.Carib = gam(Carib ~ s(doy) + s(fid, bs="re"), data=data, family = binomial("logit")) #One smoother per zone, no random effects
p.Carib = predict(m.Carib, type="response", se.fit=TRUE, newdata = dnew, exclude="s(fid)")

m.Brazil = gam(Carib ~ s(doy) + s(fid, bs="re"), data=data, family = binomial("logit")) #One smoother per zone, no random effects
p.Brazil = predict(m.Brazil, type="response", se.fit=TRUE, newdata = dnew, exclude="s(fid)")

############################
# PLOTTING PREDICTIONS
# Plot with CIs as polygons and model-estimated standard error

# Set variables
x = doy # define x axis

col.lkup = data.frame("zone" = c("Carib","Guianas","Brazil", "Other"), "col" = c("cyan3","black","green","gray"))
col.lkup$zone = as.character(col.lkup$zone)
col.lkup$col = as.character(col.lkup$col)

x = dnew$doy # define x axis
figmain = data$pop[1]
cols = col.lkup[match(zones,col.lkup[,1]),2] # Use color look-up table for each zone

# Plot and save out as pdf. 
# Add each population one by one (Already had this code, but could have done more efficiently

pdf(pdfname, width = 11, height = 8)
plot(0, 0, type = 'n', xlim = c(205,290), ylim = c(0, 1), yaxs = 'i',
     xlab = 'Day of year', ylab = 'Estimated probability of occurrence in any of 3 harvest', main = figmain) #Set up plot

# Other
m = p.Other
ucl = m$fit + m$se.fit
lcl = m$fit - m$se.fit
i.for <- order(x)
i.back <- order(x, decreasing = TRUE )
x.polygon <- c( x[i.for] , x[i.back] )
y.polygon <- c( ucl[i.for] , lcl[i.back] )
polygon( x.polygon , y.polygon , col = adjustcolor("gray", alpha.f=0.1), border = NA )
lines(x, m$fit, col = "gray") #Plot estimated probabilities

# Carib
m = p.Carib
ucl = m$fit + m$se.fit
lcl = m$fit - m$se.fit
i.for <- order(x)
i.back <- order(x, decreasing = TRUE )
x.polygon <- c( x[i.for] , x[i.back] )
y.polygon <- c( ucl[i.for] , lcl[i.back] )
polygon( x.polygon , y.polygon , col = adjustcolor("cyan3", alpha.f=0.03), border = NA )
lines(x, m$fit, col = "cyan3") #Plot estimated probabilities

# Guianas
m = p.Guianas
ucl = m$fit + m$se.fit
lcl = m$fit - m$se.fit
i.for <- order(x)
i.back <- order(x, decreasing = TRUE )
x.polygon <- c( x[i.for] , x[i.back] )
y.polygon <- c( ucl[i.for] , lcl[i.back] )
polygon( x.polygon , y.polygon , col = adjustcolor("black", alpha.f=0.03), border = NA )
lines(x, m$fit, col = "black") #Plot estimated probabilities

# Brazil
m = p.Brazil
ucl = m$fit + m$se.fit
lcl = m$fit - m$se.fit
i.for <- order(x)
i.back <- order(x, decreasing = TRUE )
x.polygon <- c( x[i.for] , x[i.back] )
y.polygon <- c( ucl[i.for] , lcl[i.back] )
polygon( x.polygon , y.polygon , col = adjustcolor("green", alpha.f=0.03), border = NA )
lines(x, m$fit, col = "green") #Plot estimated probabilities

legend(x = "topright",legend = zones, lty = 1, col = cols, ncol = 2, cex = 0.8, inset=c(0,-0.2), xpd=TRUE, bty = "n")

dev.off() 

