##############################################################################################################
# Laura McDuffie, University of Alaska Anchorage, USFWS - Lesser Yellowlegs
# Code to support: Differential harvest exposure of Lesser Yellowlegs during autumn migration
# 
# Authors: Autumn-Lynn Harrison, HarrisonAL@si.edu, Smithsonian Migratory Bird center
#
# Step 3b: Use Multinomial models to predict each population's probability of occurrence in each harvest zone
##############################################################################################################

# load libraries from config file
source("0-config.r")

# load data (output of Step 2)
load("results/02_fG_LEYE_rw_ZonesAssigned_Narrow.RData")

################## Data Prep ############################

d$fid = factor(d$id)
names(d)[which(names(d)=="zone")]="harvestzone"
# had to rename because of the use of zone in the function led to duplicate column names

# Collapse Kanuti and Mingan into larger groupings
d$pop[which(d$pop=="Kanuti")]="Anchorage"
d$pop[which(d$pop=="Mingan")]="James Bay"

pops = c("Yellowknife","Churchill", "Anchorage", "James Bay")

# Populations
# table(d$pop): Anchorage (4731), Churchill (1926), James Bay (1000), Yellowknife (1158)

################## BY POPULATION ############################
############ MULTINOMIAL NO RANDOM EFFECT ###################

# 8/18/20: Simplified code into a loop. Can also use a by-variable, but then need to plot each population anyway

for (p in 1:length(pops)) {

  data = d[d$pop==pops[p],]
  zones <- c('Other', 'Guianas', 'Carib','Brazil' ) #List of zones to consider
  sort(colSums(data[,zones])) # how many positions in each zone
  
  doy = 181:290
  
  lp <- ~ s(doy) # simple
  pdfname = paste("plots/",data$pop[1],"_Multinomial_Narrow.pdf",sep="")
  
  n.thresh = 2 # n.threshold refers to the number of data points. Only model zones with greater than many data points
  other.zone=FALSE
  
  ##Model specifications and set up
  ns <- apply(data[, zones], 2, sum) #Number of locations in each zone not including 'Other'
  zones <- names(ns[which(ns > n.thresh)]) #List of zones to model not including 'Other'
  
  if(other.zone && n.thresh > 0) n.zone <- length(zones) + 1 else n.zone <- length(zones) #Number of zones to model
  zone.code <- function(x){ #Function for coding zones (must include zero)
    if(any(x[zones] == 1)) which(x[zones] == 1) - 1 else ifelse(other.zone, n.zone - 1, NA)
  }
  zone <- unlist(apply(data, 1, zone.code)) #zone code
  
  data.mn <- cbind(data, zone = zone) #Add zone code to dataset 
  data.mn <- data.mn[which(!is.na(data.mn$zone)), ] #Remove data for zones not considered
  
  # Now the number threshold works so that this code can be put into a function
  # Will want to delete the "other" parameter. That was used to group EEZs in the same geographical area that each had small numbers, like the Central Pacific islands
  
  ## FIT MODEL
  mn.gam = gam(
    formula = c(list(reformulate(as.character(lp)[2], 'zone')), rep(list(lp), n.zone - 2)),
    data = data.mn,
    family = multinom(K = length(zones) - 1)) #Fit multinomial GAM
  
  ## Predict
  dnew <- data.frame(doy = doy) # Covariate data for prediction for simple model, without random effect
  p.hat <- predict(mn.gam, newdata = dnew, type='response', se.fit= TRUE) #Estimated probabilities
  
  # Plot with CIs as polygons and model-estimated standard error
  col.lkup = data.frame("zone" = c("Carib","Guianas","Brazil", "Other"), "col" = c("cyan3","black","green","gray"))
  col.lkup$zone = as.character(col.lkup$zone)
  col.lkup$col = as.character(col.lkup$col)
  
  x = dnew$doy # define x axis
  figmain = paste(data$pop[1], deparse(mn.gam$formula[[1]]))
  cols = col.lkup[match(zones,col.lkup[,1]),2] # Use color look-up table for each zone
  
  pdf(pdfname, width = 11, height = 8)
  plot(0, 0, type = 'n', xlim = c(150,290), ylim = c(0, 1), yaxs = 'i',
       xlab = 'Day of year', ylab = 'Estimated probability', main = figmain) #Set up plot
  for(i in 1:length(zones)) {
    ucl = p.hat$fit[, i] + p.hat$se.fit[, i]
    lcl = p.hat$fit[, i] - p.hat$se.fit[, i]
    i.for <- order(x)
    i.back <- order(x, decreasing = TRUE )
    x.polygon <- c( x[i.for] , x[i.back] )
    y.polygon <- c( ucl[i.for] , lcl[i.back] )
    polygon( x.polygon , y.polygon , col = adjustcolor(cols[i], alpha.f=0.07), border = NA )
    lines(x, p.hat$fit[, i], col = cols[i]) #Plot estimated probabilities
  }
  #legend(x = 'topright', legend = zones, lty = 1, col = cols, ncol = 4, cex = 0.8)
  legend(x = "topright",legend = zones, lty = 1, col = cols, ncol = 4, cex = 0.8, inset=c(0,-0.1), xpd=TRUE, bty = "n")
  dev.off()

}

################## BY POPULATION ############################
############ MULTINOMIAL WITH RANDOM EFFECT ###################

# Did not converge for Anchorage or James Bay
# Random effects terms were highly insignificant in the multinomial framework

# Differences from above = model specification (lp), predict specifications + pdf name
for (p in 1:length(pops)) {
  
  data = d[d$pop==pops[p],]
  #zones <- c('Other','Carib', 'Guyana', 'Brazil') #List of zones to consider
  zones <- c('Other', 'Guianas', 'Carib','Brazil') #List of zones to consider
  
  sort(colSums(data[,zones])) # how many positions in each zone
  
  doy = 181:290
  
  #zones <- c('Carib', 'Guyana', 'Brazil') #List of zones to consider
  
  lp <- ~ s(doy) + s(fid, bs = 're') #formula
  pdfname = paste("plots/",data$pop[1],"_Multinomial_Narrow_Random.pdf",sep="")
  
  n.thresh = 2 # n.threshold refers to the number of data points. Only model zones with greater than that many data points 
  other.zone=FALSE
  
  ##Model specifications and set up
  ns <- apply(data[, zones], 2, sum) #Number of locations in each zone not including 'Other'
  zones <- names(ns[which(ns > n.thresh)]) #List of zones to model not including 'Other'
  
  if(other.zone && n.thresh > 0) n.zone <- length(zones) + 1 else n.zone <- length(zones) #Number of zones to model
  zone.code <- function(x){ #Function for coding zones (must include zero)
    if(any(x[zones] == 1)) which(x[zones] == 1) - 1 else ifelse(other.zone, n.zone - 1, NA)
  }
  zone <- unlist(apply(data, 1, zone.code)) #zone code
  
  data.mn <- cbind(data, zone = zone) #Add zone code to dataset (also add dummy variable for predictions marginalized over random effect of fid)
  data.mn <- data.mn[which(!is.na(data.mn$zone)), ] #Remove data for zones not considered
  
  # Now the number threshold works so that this code can be put into a function
  # Will want to delete the "other" parameter. That was used to group EEZs in the same geographical area that each had small numbers, like the Central Pacific islands
  
  ## FIT MODEL
  mn.gam = gam(
    formula = c(list(reformulate(as.character(lp)[2], 'zone')), rep(list(lp), n.zone - 2)),
    data = data.mn,
    family = multinom(K = length(zones) - 1)) #Fit multinomial GAM
  
  ## Predict
  dnew <- data.frame(doy = doy, fid = data.mn$fid[1]) # Covariate data for prediction
  p.hat <- predict(mn.gam, newdata = dnew, type='response', se.fit= TRUE, exclude="s(fid)") #Estimated probabilities
  
  # Plot with CIs as polygons and model-estimated standard error
  col.lkup = data.frame("zone" = c("Carib","Guianas","Brazil", "Other"), "col" = c("cyan3","black","green","gray"))
  col.lkup$zone = as.character(col.lkup$zone)
  col.lkup$col = as.character(col.lkup$col)
  
  x = dnew$doy # define x axis
  figmain = paste(data$pop[1], deparse(mn.gam$formula[[1]]))
  cols = col.lkup[match(zones,col.lkup[,1]),2] # Use color look-up table for each zone
  
  pdf(pdfname, width = 11, height = 8)
  plot(0, 0, type = 'n', xlim = c(150,290), ylim = c(0, 1), yaxs = 'i',
       xlab = 'Day of year', ylab = 'Estimated probability', main = figmain) #Set up plot
  for(i in 1:length(zones)) {
    ucl = p.hat$fit[, i] + p.hat$se.fit[, i]
    lcl = p.hat$fit[, i] - p.hat$se.fit[, i]
    i.for <- order(x)
    i.back <- order(x, decreasing = TRUE )
    x.polygon <- c( x[i.for] , x[i.back] )
    y.polygon <- c( ucl[i.for] , lcl[i.back] )
    polygon( x.polygon , y.polygon , col = adjustcolor(cols[i], alpha.f=0.07), border = NA )
    lines(x, p.hat$fit[, i], col = cols[i]) #Plot estimated probabilities
  }
  legend(x = 'topright', legend = zones, lty = 1, col = cols, ncol = 4, cex = 0.8)
  dev.off()
  
}


# ################## BY HARVEST ZONE ################################
# ## results could lead to misinterpretation due to small sample size
# 
# # create separate columns for each population
# x = dcast(d, as.numeric(rowid) ~ pop, length, value.var="pop")
# # x[4625:4632,] test matches original data
# d = cbind(d,x)
# rm(x)
# 
# data = d[d$harvestzone=="Guyana",]
# sort(colSums(data[,21:26])) # ee how many positions in each zone
# 
# zones <- c('Anchorage', 'Yellowknife', 'Churchill', 'James Bay',"Mingan","Kanuti") #List of zones to consider
# 
# # define model forumla
# lp <- ~ s(doy) # simple
# #lp <- ~ s(doy) + s(fid, bs = 're', by = dum) #formula
# pdfname = paste("plots/",data$harvestzone[1],"_random.pdf",sep="")
# 
# n.thresh = 2 # n.threshold refers to the number of data points. Only model zones with at least that many data points (they would be collapsed into an other category)
# other.zone=FALSE
# 
# ##Model specifications and set up
# ns <- apply(data[, zones], 2, sum) #Number of locations in each zone not including 'Other'
# zones <- names(ns[which(ns > n.thresh)]) #List of zones to model not including 'Other'
# 
# if(other.zone && n.thresh > 0) n.zone <- length(zones) + 1 else n.zone <- length(zones) #Number of zones to model
# zone.code <- function(x){ #Function for coding zones (must include zero)
#   if(any(x[zones] == 1)) which(x[zones] == 1) - 1 else ifelse(other.zone, n.zone - 1, NA)
# }
# zone <- unlist(apply(data, 1, zone.code)) #zone code
# #if(other.zone && n.thresh > 0) zones <- c(zones, 'Other') #Add 'Other' zone to list
# 
# data.mn <- cbind(data, zone = zone, dum = 1) #Add zone code to dataset (also add dummy variable for predictions marginalized over random effect of fid)
# data.mn <- data.mn[which(!is.na(data.mn$zone)), ] #Remove data for zones not considered
# 
# # Now the number threshold works so that this code can be put into a function
# # Will want to delet the "other" parameter. That was used to group EEZs in the same geographical area that each had small numbers, like the Central Pacific islands
# 
# ## FIT MODEL
# mn.gam = gam(
#   formula = c(list(reformulate(as.character(lp)[2], 'zone')), rep(list(lp), n.zone - 2)),
#   data = data.mn,
#   family = multinom(K = length(zones) - 1)) #Fit multinomial GAM
# 
# col.lkup = data.frame("zone" = c('Anchorage', 'Yellowknife', 'Churchill', 'James Bay',"Mingan","Kanuti"), "col" = c("cyan3","darkgoldenrod2","red","blue","grey","green"))
# col.lkup$zone = as.character(col.lkup$zone)
# col.lkup$col = as.character(col.lkup$col)
# 
# figmain = paste(data$harvestzone[1], deparse(mn.gam$formula[[1]]))
# pdfname = paste("plots/",data$harvestzone[1],"_random.pdf",sep="")
# 
# #doy = 181:290
# doy = min(data.mn$doy):max(data.mn$doy)
# dnew <- data.frame(doy = doy) # Covariate data for prediction for simple model, without random effect
# #dnew <- data.frame(doy = 1:365, fid = data.mn$fid[1], dum=0) # Covariate data for prediction
# p.hat <- predict(mn.gam, newdata = dnew, type='response', se.fit= TRUE) #Estimated probabilities
# 
# # Plot with CIs as polygons and model-estimated standard error
# x = dnew$doy # define x axis
# 
# cols = col.lkup[match(zones,col.lkup[,1]),2] # Use color look-up table for each zone
# 
# pdf(pdfname, width = 11, height = 8)
# plot(0, 0, type = 'n', xlim = c(150,290), ylim = c(0, 1), yaxs = 'i',
#      xlab = 'Day of year', ylab = 'Estimated probability', main = figmain) #Set up plot
# for(i in 1:length(zones)) {
#   ucl = p.hat$fit[, i] + p.hat$se.fit[, i]
#   lcl = p.hat$fit[, i] - p.hat$se.fit[, i]
#   i.for <- order(x)
#   i.back <- order(x, decreasing = TRUE )
#   x.polygon <- c( x[i.for] , x[i.back] )
#   y.polygon <- c( ucl[i.for] , lcl[i.back] )
#   polygon( x.polygon , y.polygon , col = adjustcolor(cols[i], alpha.f=0.07), border = NA )
#   lines(x, p.hat$fit[, i], col = cols[i]) #Plot estimated probabilities
# }
# legend(x = 'topright', legend = zones, lty = 1, col = cols, ncol = 4, cex = 0.8)
# dev.off()
# 
# 
