###############################
# Exposure days predictor GLM
# Laura McDuffie
# Last modified: 4/21/2021
# Predictors of total exposure days in harvest zones prior to 21 October.Only birds that occurred inside a harvest zone are included.
################################
library(ggplot2)
library(multcompView)
library(dplyr)
library(ggpubr)

setwd("c:/users/lamcduffie/Documents/Lesser_Yellowlegs/documents/Laura's_thesis/Harvest_Exposure_Chapter/exposure_duration")

LEYE <- read.csv("GLM_zone_occur.csv")
summary(LEYE)
head(LEYE)

# Convert covariates (independent variables) to factors 
LEYE$Julian <- strptime(LEYE$dept_date,"%m/%d/%Y")$yday

LEYE$sex.f <- factor(LEYE$sex)
is.factor(LEYE$sex.f)

LEYE$year.f <- factor(LEYE$year)
is.factor(LEYE$year.f)

LEYE$pop.f <- factor(LEYE$pop)
is.factor(LEYE$pop.f)


#####
## Visualize data
library(ggplot2)
# Visualize data (proportion exposed to harvest as a function of departure date):
ggplot(LEYE, aes(capt_long, exposed, color=population)) +
  theme_bw() + labs(x="Capture Longitude ", y = "Exposure Days") +
  ggtitle("Lesser Yellowlegs exposed") +
  geom_point(size=2) 

#######
## Test for correlations among predictor variables.

##First make sex and year numeric
sex.n<-ifelse(LEYE$sex=="f",1,0)
year.n<-ifelse(LEYE$year==2018,0,1)

m.corr<-matrix(NA,85,5)
m.corr[,1]<-LEYE[,4] #mass
m.corr[,2]<-LEYE[,6] #capt_long
m.corr[,3]<-LEYE[,10]# dept_date (Julian)
m.corr[,4]<-sex.n
m.corr[,5]<-year.n
colnames(m.corr)<-c("mass","long","julian","sex","year")

cor<-cor(m.corr,method="pearson")
cor
### julian and long are highly correlated (0.8043429)

#          mass       long      julian         sex        year
#mass   1.00000000  0.1200205  0.02274805  0.50795200  0.07301087
#long   0.12002051  1.0000000  0.80434287 -0.17611611  0.18202778
#julian 0.02274805  0.8043429  1.00000000 -0.25283720 -0.04406394
#sex    0.50795200 -0.1761161 -0.25283720  1.00000000  0.08281849
#year   0.07301087  0.1820278 -0.04406394  0.08281849  1.00000000

#####Figure out what type of model (negative binomial, poisson) best fits the data
library(MASS)
library(pscl)
library(vcd)
m1<-glm(exposed~ year.f + Julian + capt_long + capt_mass, data=LEYE, family = "binomial")
summary(m1)
m2<-glm(exposed~ year.f + Julian + capt_long + capt_mass ,data=LEYE, family="poisson")
summary(m2)

#Which model (poisson or nb) fits the data the best?
b.fit<-goodfit(LEYE$exposed,type="nbinom")
rootogram(b.fit)##not perfect, but fits much better than the poisson
poiss.fit<-goodfit(LEYE$exposed,type="poisson")
rootogram(poiss.fit)
AIC(m1,m2) ##AIC indicates that binomial is better than poisson (78 vs. 100)
vuong(m1,m2)# vuong test also says model 1 (nb) is better than model 2 (poisson)

##Now, test whether nb model can accurately predict the data
nd = data.frame(year.f = c("2018","2019", "2020"),Julian=mean(LEYE$Julian),capt_long=mean(LEYE$capt_long), capt_mass=mean(LEYE$capt_mass))

pred<-cbind(nd, 
            Mean = predict(m1, newdata = nd, type = "response"), 
            SE = predict(m1, newdata = nd, type = "response", se.fit = T)$se.fit
)
pred
##Means and standard errors are reasonable

###Test whether julian or longitude is better
m.long<-glm.nb(exposed~ capt_long,data=LEYE)
m.julian<-glm.nb(exposed~ Julian,data=LEYE)
AIC(m.long, m.julian) ##longitude is better, include longitude in subsequent models.

######Here's the full model
full<-glm(exposed~ capt_long + capt_mass + sex.f + year.f, data=LEYE, family = "binomial", control=glm.control(maxit=1000))
summary(full)

###I needed to tell it to do 1000 iterations in order to converge. 

## The models to test:
# Full, 
# Null,
# sex,
# year,
# capt_mass,
# capt_long,
# sex + year
# sex + capt_mass
# sex + capt_long
# year + capt_mass
# year + capt_long
# capt_mass + capt_long
# sex + year + capt_mass
# sex + year + capt_long
# sex + capt_mass + capt_long
# year + capt_mass + capt_long

#### Fit models

LEYE.fits <- vector("list")  # Create empty list to hold output from all models

# Full Model (sex + mass + capt_long)
LEYE.fits$A <- glm(exposed~ sex.f + year.f + capt_mass + capt_long, data=LEYE, family = "binomial", control=glm.control(maxit=100))
# Null Model (intercept only)
LEYE.fits$B <- glm(exposed ~1, data= LEYE, family = "binomial", control=glm.control(maxit=1000))
# Sex only model
LEYE.fits$C <- glm(exposed ~sex.f, data= LEYE, family = "binomial", control=glm.control(maxit=1000))
# Year only model
LEYE.fits$D <- glm(exposed ~year.f, data=LEYE, family = "binomial", control=glm.control(maxit=1000))
# capt_mass only
LEYE.fits$E <- glm(exposed ~capt_mass, data=LEYE, family = "binomial", control=glm.control(maxit=1000))
# capt_long only
LEYE.fits$F <- glm(exposed ~capt_long, data= LEYE, family = "binomial", control=glm.control(maxit=1000))
# sex + year
LEYE.fits$G <- glm(exposed ~sex.f + year.f, data= LEYE, family = "binomial", control=glm.control(maxit=1000))
# sex + capt_mass
LEYE.fits$H <- glm(exposed ~sex.f + capt_mass, data= LEYE, family = "binomial", control=glm.control(maxit=1000))
# sex + capt_long
LEYE.fits$I <- glm(exposed ~sex.f + capt_long, data= LEYE, family = "binomial", control=glm.control(maxit=1000))
# year + capt_mass
LEYE.fits$J <- glm(exposed ~year.f + capt_mass, data= LEYE, family = "binomial", control=glm.control(maxit=1000))
# year + capt_long
LEYE.fits$k <- glm(exposed ~year.f + capt_long, data= LEYE, family = "binomial", control=glm.control(maxit=1000))
# capt_mass + capt_long
LEYE.fits$L <- glm(exposed ~capt_mass + capt_long, data= LEYE, family = "binomial", control=glm.control(maxit=1000))
# sex + year + capt_mass
LEYE.fits$M <- glm(exposed ~sex.f + year.f + capt_mass, data= LEYE, family = "binomial", control=glm.control(maxit=1000))
# sex + year + capt_long
LEYE.fits$N <- glm(exposed ~sex.f + year.f + capt_long, data= LEYE, family = "binomial", control=glm.control(maxit=1000))
# sex + capt_mass + capt_long
LEYE.fits$O <- glm(exposed ~sex.f + capt_mass + capt_long, data= LEYE, family = "binomial", control=glm.control(maxit=1000))
# year + capt_mass + capt_long
LEYE.fits$P <- glm(exposed ~year.f + capt_mass + capt_long, data= LEYE, family = "binomial", control=glm.control(maxit=1000))


########
# Compute both the AIC values and the small-sample version (AICc) for 

library(AICcmodavg)
out <- matrix(NA, 16, 6)
dimnames(out) <- list(names(LEYE.fits), c("k", "logL", "AIC", "delAIC", "AICc", "delAICc"))

for(i in names(LEYE.fits)) {
  mod <- LEYE.fits[[i]]
  logL <- logLik(mod)
  out[i, "k"] <-  attr(logL, "df")
  out[i,"logL"] <- logL
  out[i,"AIC"] <- AIC(mod)
  out[i, "AICc"] <- AICc(mod)
}
out

out[,"delAIC"] <- out[,"AIC"] - min(out[,"AIC"])
out[,"delAICc"] <- out[,"AICc"] - min(out[,"AICc"])
round(out,2)

# Akaike weights
D <- out[,"delAIC"]    
W.aic <- exp(-0.5*D) / sum(exp(-0.5*D))
# Small-sample Akaike weights
D <- out[,"delAICc"]
W.aicc <- exp(-0.5*D) / sum(exp(-0.5*D))

W <- round(cbind(W.aic, W.aicc),3)

# Table 4 in Word document:
Tbl4 <- data.frame(Model=row.names(out), out[,c(1,5)], Waic = W.aic, 
                   delAICc = out[,"delAICc"], Waicc = W.aicc)
Tbl4

aictab(LEYE.fits, names(LEYE.fits))          # small-sample AICc (default)
aictab(LEYE.fits, names(LEYE.fits), sec=F)   # AIC

#Model selection based on AIC:
  
#   K    AIC Delta_AIC AICWt Cum.Wt     LL
# F 2  73.42      0.00  0.32   0.32 -34.71
# I 3  74.77      1.35  0.16   0.49 -34.38
# k 4  75.12      1.70  0.14   0.62 -33.56
# L 3  75.42      2.00  0.12   0.74 -34.71
# N 5  75.76      2.34  0.10   0.84 -32.88
# O 4  76.57      3.15  0.07   0.91 -34.29
# P 5  77.06      3.64  0.05   0.96 -33.53
# A 6  77.67      4.25  0.04   1.00 -32.83
# M 5 104.41     30.99  0.00   1.00 -47.21
# H 3 104.73     31.31  0.00   1.00 -49.36
# G 4 105.29     31.87  0.00   1.00 -48.65
# C 2 106.13     32.71  0.00   1.00 -51.06
# D 3 106.61     33.19  0.00   1.00 -50.31
# B 1 106.68     33.26  0.00   1.00 -52.34
# E 2 108.15     34.73  0.00   1.00 -52.08
# J 4 108.23     34.81  0.00   1.00 -50.12


summary(LEYE.fits$F)
# Intercept
5.29598 - (1.96*1.25515)=2.835886
5.29598 + (1.96*1.25515)=7.756074
# capt_long
0.05358 - (1.96*0.01137)=0.0312948
0.05358 + (1.96*0.01137)=0.0758652

summary(LEYE.fits$I)
#intercept
4.94099 - (1.96*1.30621)=2.380818
4.94099 + (1.96*1.30621)=7.501162
#sex_f
0.49100 - (1.96*0.60753)=-0.6997588
0.49100 + (1.96*0.60753)=1.681759
# capt_long
0.05270 - (1.96*0.01139)=0.0303756
0.05270 + (1.96*0.01139)=0.0750244

summary(LEYE.fits$k)
#intercept
4.17091 - (1.96*1.45040)=1.328126
4.17091 + (1.96*1.45040)=7.013694
#year.2019
1.41942 - (1.96*0.98691)=-0.5149236
1.41942 + (1.96*0.98691)=3.353764
#year.2020
1.32858 - (1.96*1.27999)=-1.1802
1.32858 + (1.96*1.27999)=3.83736
#capt_long
0.05456 - (1.96*0.01208)=0.0308832
0.05456 + (1.96*0.01208)=0.0782368

summary(LEYE.fits$L)
#Intercept
5.445325 - (1.96*4.496761)=-3.368327
5.445325 + (1.96*4.496761)=14.25898
#capt_mass
-0.001658 - (1.96*0.047899)=-0.09554004
-0.001658 + (1.96*0.047899)=0.09222404
#capt_long
0.053620 - (1.96*0.011433)=0.03121132
0.053620 + (1.96*0.011433)=0.07602868

summary(LEYE.fits$N)
#intercept
3.42378 - (1.96*1.55269)= 0.3805076
3.42378 + (1.96*1.55269)= 6.467052
#sex.fm
0.75258 - (1.96*0.2926747)= 0.1789376
0.75258 + (1.96*0.2926747)= 1.326222
#year.2019
1.69706  - (1.96*1.04766)= -0.3563536
1.69706  + (1.96*1.04766)= 3.750474
#year.2020
1.77272  - (1.96*1.35368)= -0.8804928
1.77272  + (1.96*1.35368)= 4.425933
#capt_long
0.05390  - (1.96*0.01227)= 0.0298508
0.05390  + (1.96*0.01227)= 0.0779492

summary(LEYE.fits$O)
#intercept
2.59593 - (1.96*5.46440)=-8.114294
2.59593 + (1.96*5.46440)=13.30615
#sex_m
0.65228   - (1.96*0.71221)= -0.7436516
0.65228   + (1.96*0.71221)= 2.048212
#capt_mass
0.02464 - (1.96*0.05626)=-0.0856296
0.02464 + (1.96*0.05626)=0.1349096
#capt_long
0.05171 - (1.96*0.01155)=0.029072
0.05171 + (1.96*0.01155)=0.074348

summary(LEYE.fits$P)
#intercept
5.29673 - (1.96*4.74313)= -3.999805
5.29673 + (1.96*4.74313)= 14.59326
#year.2019
1.45953 - (1.96*1.00659)= -0.5133864
1.45953 + (1.96*1.00659)= 3.432446
#year.2020
1.41670 - (1.96*1.33214)=-1.194294
1.41670 + (1.96*1.33214)=4.027694
#capt_mass
-0.01284 - (1.96*0.05119)=-0.1131724
-0.01284 + (1.96*0.05119)=0.0874924
#capt_long
0.05501 - (1.96*0.01229)=0.0309216
0.05501 + (1.96*0.01229)=0.0790984

summary(LEYE.fits$A)
#intercept
1.71045 - (1.96*5.65641)= -9.376114
1.71045 + (1.96*5.65641)= 12.79701
#sex.fm
0.85737 - (1.96*0.73320)= -0.579702
0.85737 + (1.96*0.73320)= 2.294442
#year.2019
1.66962 - (1.96*1.04610)=-0.380736
1.66962 + (1.96*1.04610)=3.719976
#year.2020
1.70675 - (1.96*1.36480)=-0.968258
1.70675 + (1.96*1.36480)=4.381758
#capt_mass
0.01832 - (1.96*0.05848)=-0.0963008
0.01832 + (1.96*0.05848)=0.1329408
#capt_long
0.05308 - (1.96*0.01247)=0.0286388
0.05308 + (1.96*0.01247)=0.0775212

summary(LEYE.fits$M)
#intercept
-9.16092 - (1.96*4.06030)=-17.11911
-9.16092 + (1.96*4.06030)=-1.202732
#sex.m
1.39951 - (1.96*0.60517)=0.2133768
1.39951 + (1.96*0.60517)=2.585643
#year.2019
1.47460 - (1.96*0.82056)=-0.1336976
1.47460 + (1.96*0.82056)=3.082898
#year.2020
1.50426 - (1.96*0.94481)=-0.3475676
1.50426 + (1.96*0.94481)=3.356088
#capt_mass
0.07295 - (1.96*0.04348)=-0.0122708
0.07295 + (1.96*0.04348)=0.1581708

summary(LEYE.fits$H)
#intercept
-8.29382 - (1.96*3.94916)=-16.03417
-8.29382 + (1.96*3.94916)=-0.5534664
#sex.m
1.34361 - (1.96*0.60071)=0.1662184
1.34361 + (1.96*0.60071)=2.521002
#capt_mass
0.07759 - (1.96*0.04259)=-0.0058864
0.07759 + (1.96*0.04259)=0.1610664

summary(LEYE.fits$G)
#intercept
-2.5690 - (1.96*0.8361)=-4.207756
-2.5690 + (1.96*0.8361)=-0.930244
#sex.f
0.9031 - (1.96*0.5023)=-0.081408
0.9031 + (1.96*0.5023)=1.887608
#year.2019
1.5083 - (1.96*0.8207)=-0.100272
1.5083 + (1.96*0.8207)=3.116872
#year.2020
1.6764 - (1.96*0.9372)=-0.160512
1.6764 + (1.96*0.9372)=3.513312

summary(LEYE.fits$C)
#intercept
-1.1856 - (1.96*0.3445)=-1.86082
-1.1856 + (1.96*0.3445)=-0.51038
#sex.m
0.7582 - (1.96*0.4784)=-0.179464
0.7582 + (1.96*0.4784)=1.695864

summary(LEYE.fits$D)
#intercept
-2.0149 - (1.96*0.7528)=-3.490388
-2.0149 + (1.96*0.7528)=-0.539412
#year.2019
1.4088 - (1.96*0.8078)=-0.174488
1.4088 + (1.96*0.8078)=2.992088
#year.2020
1.4088 - (1.96*0.9079)=-0.370684
1.4088 + (1.96*0.9079)=3.188284

summary(LEYE.fits$B)
#intercept
-0.8194 - (1.96*0.2354)=-1.280784
-0.8194 + (1.96*0.2354)=-0.358016

summary(LEYE.fits$E)
#intercept
-3.03926 - (1.96*3.06056)=-9.037958
-3.03926 + (1.96*3.06056)=2.959438
#capt_mass
0.02525 - (1.96*0.03463)=-0.0426248
0.02525 + (1.96*0.03463)=0.0931248

summary(LEYE.fits$J)
#intercept
-3.96578 - (1.96*3.25978)=-10.35495
-3.96578 + (1.96*3.25978)=2.423389
#year.2019
1.40411 - (1.96*0.80897)=-0.1814712
1.40411 + (1.96*0.80897)=2.989691
#year.2020
1.33704 - (1.96*0.91559)=-0.4575164
1.33704 + (1.96*0.91559)=3.131596
#capt_mass
0.02239 - (1.96*0.03623)=-0.0486208
0.02239 + (1.96*0.03623)=0.0934008



### Conculsion: Capture longitude nearly a significant predictor of presence in a exposure region.

nd = data.frame(capt_long = seq(min(LEYE$capt_long),max(LEYE$capt_long),length.out=20))
m.long<-glm(exposed~ capt_long,data=LEYE)
summary(m.long)
pred<-cbind(nd, 
            Mean = predict(m.long, newdata = nd, type = "response"), 
            SE = predict(m.long, newdata = nd, type = "response", se.fit = T)$se.fit)
pred

pred$lwr <- pred$Mean-1.96*pred$SE
pred$upr <- pred$Mean+1.96*pred$SE

plot(pred$capt_long,pred$Mean,type="l",xlab="Longitude of capture",ylab="Days exposed")
lines(pred$capt_long,pred$Mean+1.96*pred$SE,lty=5)
lines(pred$capt_long,pred$Mean-1.96*pred$SE,lty=5)
points(LEYE$capt_long,LEYE$exposed,pch=16)

# Visualize: model-estimated relationship super-imposed on the raw data
ggplot(pred, aes(capt_long, Mean)) +
  labs(x="capture longitude", y = "exposure days") +
  geom_line(color="blue", size=1.2) +
  geom_ribbon(aes(ymin = lwr, ymax = upr, fill = NULL), alpha = .15)+
  geom_point(data = LEYE, aes(capt_long, exposed)) +
  coord_cartesian(ylim = c(0, 60), xlim =c(-148,-70))+
  theme_classic()




